@@ -13,23 +13,25 @@
 #include <QDebug>
 #include <QProcess>
 
-const QString CONFIG_FILE = QStringLiteral("plasmamobilerc");
-const QString SAVED_CONFIG_GROUP = QStringLiteral("SavedConfig");
+using namespace Qt::Literals::StringLiterals;
+
+const QString CONFIG_FILE = u"plasmamobilerc"_s;
+const QString SAVED_CONFIG_GROUP = u"SavedConfig"_s;
 
 Settings::Settings(QObject *parent)
     : QObject{parent}
-    , m_isMobilePlatform{KRuntimePlatform::runtimePlatform().contains(QStringLiteral("phone"))}
+    , m_isMobilePlatform{KRuntimePlatform::runtimePlatform().contains(u"phone"_s)}
     , m_mobileConfig{KSharedConfig::openConfig(CONFIG_FILE, KConfig::SimpleConfig)}
-    , m_kwinrcConfig{KSharedConfig::openConfig(QStringLiteral("kwinrc"), KConfig::SimpleConfig)}
-    , m_appBlacklistConfig{KSharedConfig::openConfig(QStringLiteral("applications-blacklistrc"), KConfig::SimpleConfig)}
-    , m_kdeglobalsConfig{KSharedConfig::openConfig(QStringLiteral("kdeglobals"), KConfig::SimpleConfig)}
+    , m_kwinrcConfig{KSharedConfig::openConfig(u"kwinrc"_s, KConfig::SimpleConfig)}
+    , m_appBlacklistConfig{KSharedConfig::openConfig(u"applications-blacklistrc"_s, KConfig::SimpleConfig)}
+    , m_kdeglobalsConfig{KSharedConfig::openConfig(u"kdeglobals"_s, KConfig::SimpleConfig)}
     , m_configWatcher{KConfigWatcher::create(m_mobileConfig)}
 {
 }
 
-Settings *Settings::self()
+Settings &Settings::self()
 {
-    static Settings *settings = new Settings;
+    static Settings settings;
     return settings;
 }
 
@@ -49,17 +51,17 @@ void Settings::applyConfiguration()
 void Settings::loadSavedConfiguration()
 {
     // kwinrc
-    loadKeys(QStringLiteral("kwinrc"), m_kwinrcConfig, getKwinrcSettings(m_mobileConfig));
+    loadKeys(u"kwinrc"_s, m_kwinrcConfig, getKwinrcSettings(m_mobileConfig));
     m_kwinrcConfig->sync();
     reloadKWinConfig();
 
     // applications-blacklistrc
-    loadKeys(QStringLiteral("applications-blacklistrc"), m_appBlacklistConfig, APPLICATIONS_BLACKLIST_DEFAULT_SETTINGS);
+    loadKeys(u"applications-blacklistrc"_s, m_appBlacklistConfig, APPLICATIONS_BLACKLIST_DEFAULT_SETTINGS);
     m_appBlacklistConfig->sync();
 
     // kdeglobals
-    loadKeys(QStringLiteral("kdeglobals"), m_kdeglobalsConfig, KDEGLOBALS_DEFAULT_SETTINGS);
-    loadKeys(QStringLiteral("kdeglobals"), m_kdeglobalsConfig, KDEGLOBALS_SETTINGS);
+    loadKeys(u"kdeglobals"_s, m_kdeglobalsConfig, KDEGLOBALS_DEFAULT_SETTINGS);
+    loadKeys(u"kdeglobals"_s, m_kdeglobalsConfig, KDEGLOBALS_SETTINGS);
     m_kdeglobalsConfig->sync();
 
     // save our changes
@@ -69,23 +71,21 @@ void Settings::loadSavedConfiguration()
 void Settings::applyMobileConfiguration()
 {
     // kwinrc
-    writeKeys(QStringLiteral("kwinrc"), m_kwinrcConfig, getKwinrcSettings(m_mobileConfig), false);
+    writeKeys(u"kwinrc"_s, m_kwinrcConfig, getKwinrcSettings(m_mobileConfig), false);
     m_kwinrcConfig->sync();
     reloadKWinConfig();
 
     // applications-blacklistrc
-    writeKeys(QStringLiteral("applications-blacklistrc"),
+    writeKeys(u"applications-blacklistrc"_s,
               m_appBlacklistConfig,
               APPLICATIONS_BLACKLIST_DEFAULT_SETTINGS,
               true); // only write entries if they are not already defined in the config
     m_appBlacklistConfig->sync();
 
     // kdeglobals
-    writeKeys(QStringLiteral("kdeglobals"),
-              m_kdeglobalsConfig,
-              KDEGLOBALS_DEFAULT_SETTINGS,
+    writeKeys(u"kdeglobals"_s, m_kdeglobalsConfig, KDEGLOBALS_DEFAULT_SETTINGS,
               true); // only write entries if they are not already defined in the config
-    writeKeys(QStringLiteral("kdeglobals"), m_kdeglobalsConfig, KDEGLOBALS_SETTINGS, false);
+    writeKeys(u"kdeglobals"_s, m_kdeglobalsConfig, KDEGLOBALS_SETTINGS, false);
     m_kdeglobalsConfig->sync();
 
     // save our changes
@@ -94,10 +94,12 @@ void Settings::applyMobileConfiguration()
 
 void Settings::writeKeys(const QString &fileName, KSharedConfig::Ptr &config, const QMap<QString, QMap<QString, QVariant>> &settings, bool overwriteOnlyIfEmpty)
 {
-    for (auto groupName : settings.keys()) {
+    const auto groupNames = settings.keys();
+    for (const auto &groupName : groupNames) {
         auto group = KConfigGroup{config, groupName};
 
-        for (auto key : settings[groupName].keys()) {
+        const auto keys = settings[groupName].keys();
+        for (const auto &key : keys) {
             if (!group.hasKey(key) || !overwriteOnlyIfEmpty) {
                 // save key
                 saveConfigSetting(fileName, groupName, key, group.readEntry(key));
@@ -111,10 +113,12 @@ void Settings::writeKeys(const QString &fileName, KSharedConfig::Ptr &config, co
 
 void Settings::loadKeys(const QString &fileName, KSharedConfig::Ptr &config, const QMap<QString, QMap<QString, QVariant>> &settings)
 {
-    for (auto groupName : settings.keys()) {
-        auto group = KConfigGroup{config, groupName};
+    const auto groupNames = settings.keys();
+    for (const auto &groupName : groupNames) {
+        const auto group = KConfigGroup{config, groupName};
 
-        for (auto key : settings[groupName].keys()) {
+        const auto keys = settings[groupName].keys();
+        for (const auto &key : keys) {
             loadSavedConfigSetting(config, fileName, groupName, key);
         }
     }
@@ -123,8 +127,8 @@ void Settings::loadKeys(const QString &fileName, KSharedConfig::Ptr &config, con
 // NOTE: this only saves a value if it hasn't already been saved
 void Settings::saveConfigSetting(const QString &fileName, const QString &group, const QString &key, const QVariant value)
 {
-    auto savedGroup = KConfigGroup{m_mobileConfig, SAVED_CONFIG_GROUP};
-    auto fileGroup = KConfigGroup{&savedGroup, fileName};
+    const auto savedGroup = KConfigGroup{m_mobileConfig, SAVED_CONFIG_GROUP};
+    const auto fileGroup = KConfigGroup{&savedGroup, fileName};
     auto keyGroup = KConfigGroup{&fileGroup, group};
 
     if (!keyGroup.hasKey(key)) {
@@ -150,7 +154,7 @@ const QString Settings::loadSavedConfigSetting(KSharedConfig::Ptr &config, const
     auto configGroup = KConfigGroup{config, group};
 
     if ((!configGroup.hasKey(key) || configGroup.readEntry(key) != value) && write) {
-        qCDebug(LOGGING_CATEGORY) << "In" << fileName << "loading saved value of" << key << "which is" << value;
+        qCDebug(LOGGING_CATEGORY) << "In" << fileName << "loading saved value of" << key << "which is" << value << "in" << group;
 
         if (value.isEmpty()) { // delete blank entries!
             configGroup.deleteEntry(key);
@@ -166,6 +170,6 @@ const QString Settings::loadSavedConfigSetting(KSharedConfig::Ptr &config, const
 
 void Settings::reloadKWinConfig()
 {
-    QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/KWin"), QStringLiteral("org.kde.KWin"), QStringLiteral("reloadConfig"));
+    QDBusMessage message = QDBusMessage::createSignal(u"/KWin"_s, u"org.kde.KWin"_s, u"reloadConfig"_s);
     QDBusConnection::sessionBus().send(message);
 }
